@@ -42,6 +42,8 @@ static PyObject *createInstance(PyObject *obj, PyObject *args)
 
     DynamsoftMrzReader* reader = PyObject_New(DynamsoftMrzReader, &DynamsoftMrzReaderType);
     reader->handler = DLR_CreateInstance();
+    reader->worker = NULL;
+    reader->callback = NULL;
     return (PyObject *)reader;
 }
 
@@ -100,3 +102,4 @@ PyMODINIT_FUNC PyInit_mrzscanner(void)
     return module;
 }
 
+
